@@ -14,7 +14,7 @@ use crate::{
 pub struct Hit {
     pub name: String,
     pub path: Vec<String>,
-    pub link: String,
+    pub link: Vec<String>,
     pub docs: Option<String>,
     #[serde(skip)]
     similarities: Similarities,
@@ -172,7 +172,7 @@ impl Index {
         krate_name: &str,
         item: &types::Item,
         impl_: Option<&types::Impl>,
-    ) -> Result<(Vec<String>, String)> {
+    ) -> Result<(Vec<String>, Vec<String>)> {
         assert!(matches!(
             item.inner,
             types::ItemEnum::Function(_) | types::ItemEnum::Method(_)
@@ -269,7 +269,7 @@ impl Index {
                 if let Some(l) = link.last_mut() {
                     *l = format!("fn.{}.html", l);
                 }
-                Ok((path.clone(), link.join("/")))
+                Ok((path.clone(), link))
             }
             types::ItemEnum::Method(_) => {
                 path.push(item.name.clone().unwrap()); // SAFETY: all methods has its name.
@@ -277,7 +277,7 @@ impl Index {
                 if let Some(l) = link.last_mut() {
                     *l = format!("#method.{}", l);
                 }
-                Ok((path.clone(), link.join("/")))
+                Ok((path.clone(), link))
             }
             // SAFETY: Already asserted at the beginning of this function.
             _ => unreachable!(),
@@ -289,13 +289,8 @@ impl Index {
 mod tests {
     use std::collections::HashSet;
 
-    use smallvec::{smallvec, SmallVec};
-
     use super::*;
-    use crate::compare::{
-        DiscreteSimilarity::*,
-        Similarity::{self, *},
-    };
+    use crate::compare::{DiscreteSimilarity::*, Similarity::*};
     use crate::query::{FnDecl, FnRetTy, Function};
 
     fn krate() -> types::Crate {
@@ -355,10 +350,9 @@ mod tests {
         let mut generics = types::Generics::default();
         let mut substs = HashMap::default();
 
-        let expected: SmallVec<[_; 10]> = smallvec![Continuous(0.0)];
         assert_eq!(
             query.compare(&item, &krate, &mut generics, &mut substs),
-            expected
+            vec![Continuous(0.0)]
         )
     }
 
@@ -377,8 +371,9 @@ mod tests {
         let mut generics = types::Generics::default();
         let mut substs = HashMap::default();
 
-        let expected: SmallVec<[Similarity; 10]> =
-            smallvec![Discrete(Equivalent), Discrete(Equivalent)];
-        assert_eq!(q.compare(&i, &krate, &mut generics, &mut substs), expected)
+        assert_eq!(
+            q.compare(&i, &krate, &mut generics, &mut substs),
+            vec![Discrete(Equivalent), Discrete(Equivalent)]
+        )
     }
 }
